@@ -733,9 +733,9 @@ std::istream &FileMetaInformation::ReadCompatInternal(std::istream &is)
 //  if( t.GetGroup() == 0x0002 )
     {
     // Purposely not Re-use ReadVR since we can read VR_END
-    char vr_str[2];
-    is.read(vr_str, 2);
-    if( VR::IsValid(vr_str) )
+    char vr_str0[2];
+    is.read(vr_str0, 2);
+    if( VR::IsValid(vr_str0) )
       {
       MetaInformationTS = TransferSyntax::Explicit;
       // Hourah !
@@ -780,7 +780,7 @@ std::istream &FileMetaInformation::ReadCompatInternal(std::istream &is)
       // Now is a good time to find out the dataset transfer syntax
       try {
       ComputeDataSetTransferSyntax();
-      } catch( gdcm::Exception & ex ) {
+      } catch( gdcm::Exception & ) {
         // We were able to read some of the Meta Header, but failed to compute the DataSetTS
         // technically GDCM is able to cope with any value here. But be kind and try to have a good guess:
      
