@@ -420,17 +420,11 @@ bool Reader::InternalReadCommon(const T_Caller &caller)
       throw Exception( "Meta Header issue" );
       }
 
-  //std::cerr << ts.GetNegociatedType() << std::endl;
-  //std::cerr << TransferSyntax::GetTSString(ts) << std::endl;
   // Special case where the dataset was compressed using the deflate
   // algorithm
   if( ts == TransferSyntax::DeflatedExplicitVRLittleEndian )
     {
-#if 0
-  std::ofstream out( "/tmp/deflate.raw", std::ios::binary );
-  out << is.rdbuf();
-  out.close();
-#endif
+
     zlib_stream::zip_istream gzis( is );
     // FIXME: we also know in this case that we are dealing with Explicit:
     assert( ts.GetNegociatedType() == TransferSyntax::Explicit );
@@ -639,30 +633,6 @@ bool Reader::InternalReadCommon(const T_Caller &caller)
             // ExplicitImplicitDataElement class instead.
             // Simply rethrow the exception for now.
             throw;
-#if 0
-            is.clear();
-            if( haspreamble )
-              {
-              is.seekg(128+4, std::ios::beg);
-              }
-            else
-              {
-              is.seekg(0, std::ios::beg);
-              }
-            if( hasmetaheader )
-              {
-              // FIXME: we are reading twice the same meta-header, we succedeed the first time...
-              // We should be able to seek to proper place instead of re-reading
-              FileMetaInformation header;
-              header.Read(is);
-              }
-
-            // Explicit/Implicit
-            gdcmWarningMacro( "Attempt to read file with explicit/implicit" );
-            F->GetDataSet().Clear(); // remove garbage from 1st attempt...
-            //F->GetDataSet().template Read<UNExplicitImplicitDataElement,SwapperNoOp>(is);
-            caller.template ReadCommon<UNExplicitImplicitDataElement,SwapperNoOp>(is);
-#endif
             }
           }
         }
@@ -734,11 +704,6 @@ bool Reader::InternalReadCommon(const T_Caller &caller)
     gdcmWarningMacro( "Unknown exception" );
     success = false;
     }
-  //  if( !success )
-  //    {
-  //    F->GetHeader().Clear();
-  //    F->GetDataSet().Clear();
-  //    }
 
   // FIXME : call this function twice...
   if (Ifstream && Ifstream->is_open())
@@ -752,6 +717,10 @@ bool Reader::InternalReadCommon(const T_Caller &caller)
   return success;
 }
 
+static inline bool isasciiupper( char c ) {
+  return c >= 'A' && c <= 'Z';
+}
+
 // This function re-implements code from:
 // http://www.dclunie.com/medical-image-faq/html/part2.html#DICOMTransferSyntaxDetermination
 // The above code does not work well for random file. It implicitly assumes we
@@ -764,8 +733,8 @@ bool Reader::CanRead() const
 {
   // fastpath
   std::istream &is = *Stream;
-  assert( is.good() );
-  assert( is.tellg() == std::streampos(0) );
+  if( is.bad() ) return false;
+  if( is.tellg() != std::streampos(0) ) return false;
     {
     is.seekg( 128, std::ios::beg ); // we ignore return value as we test is.good()
     char b[4];
@@ -780,8 +749,6 @@ bool Reader::CanRead() const
   bool bigendian = false;
   bool explicitvr = false;
   is.clear();
-  //is.seekg(0, std::ios::end);
-  //std::streampos filelen = is.tellg();
   is.seekg(0, std::ios::beg);
 
   char b[8];
@@ -798,7 +765,7 @@ bool Reader::CanRead() const
       if (b[4] < b[7]) bigendian=true;
       }
     // else littleendian
-    if (isupper(b[4]) && isupper(b[5])) explicitvr=true;
+    if (isasciiupper(b[4]) && isasciiupper(b[5])) explicitvr=true;
     }
   SwapCode sc = SwapCode::Unknown;
   TransferSyntax::NegociatedType nts = TransferSyntax::Unknown;
@@ -843,137 +810,6 @@ bool Reader::CanRead() const
       nts = TransferSyntax::Implicit;
     }
 
-#if 0
-  is.clear();
-  is.seekg(0, std::ios::end);
-  std::streampos filelen = is.tellg();
-  is.seekg(0, std::ios::beg);
-  Tag t;
-  VL gl; // group length
-  if( bigendian )
-    {
-    if( !t.Read<SwapperDoOp>(is) )
-      {
-      is.clear();
-      is.seekg(0, std::ios::beg);
-      return false;
-      }
-    }
-  else
-    {
-    if( !t.Read<SwapperNoOp>(is) )
-      {
-      is.clear();
-      is.seekg(0, std::ios::beg);
-      return false;
-      }
-    }
-  if( t.GetGroup() % 2 == 0 )
-    {
-    switch( t.GetGroup() )
-      {
-    case 0x0002:
-    //case 0x0004: // DICOMDIR is for media, thus FMI is compulsory
-    case 0x0008:
-      sc = SwapCode::LittleEndian;
-      break;
-    //case 0x0200: // FMI is Explicit VR Little Endian...
-    case 0x0800:
-      sc = SwapCode::BigEndian;
-      break;
-    default:
-      ;
-      }
-    if( sc != SwapCode::Unknown )
-      {
-      // Purposely not Re-use ReadVR since we can read VR_END
-      char vr_str[3];
-      is.read(vr_str, 2);
-      vr_str[2] = '\0';
-      // Cannot use GetVRTypeFromFile since is assert ...
-      VR::VRType vr = VR::GetVRType(vr_str);
-      if( vr != VR::VR_END )
-        {
-        nts = TransferSyntax::Explicit;
-        }
-      else
-        {
-        assert( !(VR::IsSwap(vr_str)));
-        is.seekg(-2, std::ios::cur); // Seek back
-        gl.Read<SwapperNoOp>(is);
-
-        if( t.GetElement() == 0x0000 )
-          {
-          switch(gl)
-            {
-          case 0x00000004 :
-            assert( sc == SwapCode::LittleEndian);    // 1234
-            sc = SwapCode::LittleEndian;    // 1234
-            break;
-          case 0x04000000 :
-            assert( sc == SwapCode::BigEndian);    // 1234
-            sc = SwapCode::BigEndian;       // 4321
-            break;
-          case 0x00040000 :
-            sc = SwapCode::BadLittleEndian; // 3412
-            gdcmWarningMacro( "Bad Little Endian" );
-            break;
-          case 0x00000400 :
-            sc = SwapCode::BadBigEndian;    // 2143
-            gdcmWarningMacro( "Bad Big Endian" );
-            break;
-          default:
-            ;
-            }
-          }
-        if( gl && gl < filelen )
-          nts = TransferSyntax::Implicit;
-        }
-      }
-    }
-  else
-    {
-    // US-IRAD-NoPreambleStartWith0003.dcm
-    gdcmDebugMacro( "Start with a private tag creator" );
-    if( t.GetGroup() > 0x0002 && t.GetGroup() < 0x8 )
-      {
-      switch( t.GetElement() )
-        {
-      case 0x0010:
-        sc = SwapCode::LittleEndian;
-        break;
-      default:
-        ;
-        }
-      }
-    if( sc != SwapCode::Unknown )
-      {
-      // Purposely not Re-use ReadVR since we can read VR_END
-      char vr_str[3];
-      is.read(vr_str, 2);
-      vr_str[2] = '\0';
-      // Cannot use GetVRTypeFromFile since is assert ...
-      VR::VRType vr = VR::GetVRType(vr_str);
-      if( vr != VR::VR_END )
-        {
-        nts = TransferSyntax::Explicit;
-        }
-      else
-        {
-        assert( !(VR::IsSwap(vr_str)));
-        is.seekg(-2, std::ios::cur); // Seek back
-        gl.Read<SwapperNoOp>(is);
-        if( t.GetElement() == 0x0000 )
-          {
-          assert( gl == 0x4 || gl == 0x04000000 );
-          }
-        if( gl && gl < filelen )
-          nts = TransferSyntax::Implicit;
-        }
-      }
-    }
-
-#endif
   // reset in all other cases:
   is.clear();
   is.seekg(0, std::ios::beg);
@@ -984,16 +820,6 @@ bool Reader::CanRead() const
   if( nts == TransferSyntax::Explicit && sc == SwapCode::LittleEndian ) return true;
   if( nts == TransferSyntax::Explicit && sc == SwapCode::BigEndian ) return true;
 
-//  assert( nts == TransferSyntax::Unknown );
-//  if( sc != SwapCode::Unknown )
-//    {
-//    gdcm::Reader r;
-//    r.SetStream( is );
-//    is.clear();
-//    is.seekg(0, std::ios::beg);
-//    return r.Read();
-//    }
-
   return false;
 }
 
