@@ -43,7 +43,7 @@ namespace gdcm
  */
 
 static const char *PIStrings[] = {
-  "UNKNOW",
+  "UNKNOWN",
   "MONOCHROME1 ",
   "MONOCHROME2 ",
   "PALETTE COLOR ",
@@ -111,7 +111,7 @@ bool PhotometricInterpretation::IsRetired(PIType pi)
 
 unsigned short PhotometricInterpretation::GetSamplesPerPixel() const
 {
-  if ( PIField == UNKNOW ) return 0;
+  if ( PIField == UNKNOWN ) return 0;
   else if( PIField == MONOCHROME1
    || PIField == MONOCHROME2
    || PIField == PALETTE_COLOR )
@@ -151,6 +151,7 @@ bool PhotometricInterpretation::IsLossless() const
   switch ( PIField )
     {
   case MONOCHROME1:
+  /* technically MPEG-2 is lossy however the PI is set to MONOCHROME2 */
   case MONOCHROME2:
   case PALETTE_COLOR:
   case RGB:
@@ -160,19 +161,17 @@ bool PhotometricInterpretation::IsLossless() const
   case YBR_FULL:
   case YBR_RCT:
     return true;
-    break;
   case YBR_FULL_422:
   case YBR_PARTIAL_422:
   case YBR_PARTIAL_420:
   case YBR_ICT:
     return false;
-    break;
   default:
     assert(0);
     return false;
     }
 
-  assert( 0 ); // technically one should not reach here, unless UNKNOW ...
+  assert( 0 ); // technically one should not reach here, unless UNKNOWN ...
   return false;
 }
 
