@@ -249,6 +249,10 @@ static const char * const gdcmMediaStorageDataFiles[][2] = {
 { "JPEG_LS_InvalidEscapeSequence_COM_padding.dcm" , "1.2.840.10008.5.1.4.1.1.7" },
 { "LengthOfItemLarger.dcm" , "1.2.840.10008.5.1.4.1.1.4" },
 { "GE_MR_0025xx1bProtocolDataBlockXML.dcm" , "1.2.840.10008.5.1.4.1.1.4" },
+{ "MITRA_CORNELL.dcm" , "1.2.840.10008.5.1.4.1.1.7" },
+{ "EmptyIcon_Bug417.dcm" , "1.2.840.10008.5.1.4.1.1.2" },
+{ "EnhancedWithIPPPerFrameIOPShared.dcm" , "1.2.840.10008.5.1.4.1.1.13.1.2" },
+{ "FUJI-ffff-MONO1-J2K.dcm" , "1.2.840.10008.5.1.4.1.1.1" },
 
 /* Stopping condition */
 { 0 ,0 }
